@@ -248,7 +248,12 @@ class spacy_ner_schema(object):
 						dp['filename'] = key
 						dp['key'] = el['text']
 						dp['text'] = el['text']
-						dp['lm'] = self.init.storage.load_file_metadata_global(key)['last_modified']
+						print(labels)
+						print(el['entities'])
+						if labels == schema[el['text']]['entities']:
+							dp['lm'] = schema[el['text']]['lm']	
+						else:
+							dp['lm'] = self.init.storage.load_file_metadata_global(key)['last_modified']
 						dp['entities'] = labels
 						dp['entity_types'] = [label['type'] for label in labels]
 						dp['n_entities'] = len(dp['entities'])
