@@ -40,6 +40,7 @@ class yolo_schema(object):
 
 		ls, _ = self.init.storage.load_dataset_list()
 		self.ls = ls
+		self.ls_set = set(self.ls)
 
 	def get_schema_from_key(self, key):
 		dp = {}
@@ -58,12 +59,12 @@ class yolo_schema(object):
 		schema = {}
 		current = self.init.load_current()
 
-		t0 = time.time()
+		# t0 = time.time()
 		with Pool(processes=6) as pool:
 			arr_res =  pool.map(self.get_schema_from_key, current['keys'])
 		
 		schema['len'] = len(arr_res)
-		print(f'time to compute parallelized {time.time()-t0}s')
+		# print(f'time to compute parallelized {time.time()-t0}s')
 
 		return True
 
@@ -74,18 +75,22 @@ class yolo_schema(object):
 		k = 0
 		idx = 0
 
+		lm = current['lm']
+
+		# TODO: Parallelize
 		# finds the images
+		
 		for key in current['keys']:
 			if self.is_image(key):
-				dp = {}
 				labels = self.get_labels(key)
-				dp['key'] = key
-				dp['lm'] = current['lm'][idx]
-				dp['classes'] = [labels[label]['0'] for label in labels]
-				dp['labels'] = labels
-				dp['n_classes'] = len(dp['classes'])
+				dp = {}
 				dp['tags'] = []
 				dp['slices'] = []
+				dp['key'] = key
+				dp['lm'] = lm[idx]
+				dp['classes'] = [labels[label]['0'] for label in labels]
+				dp['labels'] = labels
+				dp['n_classes'] = len(labels)
 				dp['resolution'] = self.get_resolution(key)
 				dp['size'] = self.init.storage.get_size_of_file_global(key)/1024
 				schema[str(k)] = dp
@@ -130,6 +135,7 @@ class yolo_schema(object):
 		self.selected_version = version
 		self.version_schema = schema_file
 		self.ls = keys.values()
+		self.ls_set = set(self.ls)
 
 	def reset_to_current_version(self):
 		self.in_version = False
@@ -140,7 +146,10 @@ class yolo_schema(object):
 		self.sliced = None
 
 		ls, _ = self.init.storage.load_dataset_list()
+		# DO NOT modify self.ls without also modifying ls_set
 		self.ls = ls
+		self.ls_set = set(self.ls)
+		
 		self.schema = json.load(self.init.storage.load_file_global(self.schema_path))
 
 		return True
@@ -173,7 +182,8 @@ class yolo_schema(object):
 		n_size = {}
 		n_tags = {}
 		n_slices = {}
-
+		# TODO: Parallelize
+		
 		for val in schema:
 			if type(self.schema[val]) is dict:
 				if not len(schema[val]['classes']) in classes_per_image:
@@ -234,7 +244,7 @@ class yolo_schema(object):
 			# loads image string
 			t0 = time.time()
 			img_str = self.init.storage.load_file_global(filename)
-			print(f'time to load from s3 {time.time()-t0}s')
+			print(f'time to load image from {self.init.storage.type} {time.time()-t0}s')
 			
 			# formats to cv2
 			nparr = np.fromstring(img_str.read(), np.uint8)
@@ -521,14 +531,19 @@ class yolo_schema(object):
 
 	def get_resolution(self, key):
 		# reads image
-		img_str = self.init.storage.load_file_global(key)
-		
-		# formats to cv2
-		nparr = np.fromstring(img_str.read(), np.uint8)
-		im = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
+		if self.init.storage.type == 'local':
+			# HACK: in local it is faster to just read with opencv and not load the full image
+			im = cv2.imread(key) 
+			return str(im.shape[1]) + 'x' + str(im.shape[0])
+		else:
+			img_str = self.init.storage.load_file_global(key)
+			
+			# formats to cv2
+			nparr = np.fromstring(img_str.read(), np.uint8)
+			im = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
 
-		# returns shape
-		return str(im.shape[1]) + 'x' + str(im.shape[0])
+			# returns shape
+			return str(im.shape[1]) + 'x' + str(im.shape[0])
 
 	def label_name(self, class_number):
 		return str(class_number)
@@ -540,9 +555,7 @@ class yolo_schema(object):
 				filename = os.path.dirname(filename.replace(self.init.prefix_diffs,''))
 			basename = os.path.splitext(os.path.basename(filename))[0]
 
-			ls = set(self.ls)
-
-			matches = [match for match in ls if basename+'.txt' in match]
+			matches = [match for match in self.ls_set if basename+'.txt' in match]
 			try: 
 				labels_str = self.init.storage.load_file_global(matches[0])
 			except:
@@ -600,11 +613,18 @@ class yolo_schema(object):
 		labels_string = ''
 
 		for i in range(len(labels_array)-1):
-			cl = labels_array[str(i)]['0']
-			w = labels_array[str(i)]['1']
-			h = labels_array[str(i)]['2']
-			x = labels_array[str(i)]['3']
-			y = labels_array[str(i)]['4']
+			if type(labels_array[str(i)]) is dict:
+				cl = labels_array[str(i)]['0']
+				w = labels_array[str(i)]['1']
+				h = labels_array[str(i)]['2']
+				x = labels_array[str(i)]['3']
+				y = labels_array[str(i)]['4']
+			else:
+				cl = labels_array[str(i)][0]
+				w = labels_array[str(i)][1]
+				h = labels_array[str(i)][2]
+				x = labels_array[str(i)][3]
+				y = labels_array[str(i)][4]
 
 			labels_string = labels_string + f'{cl} {w} {h} {x} {y}\n'
 
