@@ -537,7 +537,11 @@ class API(object):
             datasets = self.get_datasets()
         except:
             datasets = {}
-        self.config['schema'] = datasets[self.storage_name]['schema']
+        
+        try:
+            self.config['schema'] = datasets[self.storage_name]['schema']
+        except:
+            self.config['schema'] = 'files'
 
         if config['type'] == 'local':
             cloud = Local()
@@ -566,7 +570,10 @@ class API(object):
         self.dataset_name = config['dataset']
 
         datasets = self.get_datasets()
-        self.config['schema'] = datasets[self.storage_name]['schema']
+        try:
+            self.config['schema'] = datasets[self.storage_name]['schema']
+        except:
+            self.config['schema'] = 'files'
 
         if config['type'] == 'local':
             cloud = Local()
@@ -614,6 +621,11 @@ class API(object):
         add_from_binary(self.Initializer, filename, binary)
         return True
 
+    def upload_file_local_path(self, filename='', target_path=''):
+        assert(filename != '')
+        add(self.Initializer,[filename],target_path)
+        return True
+
     def start_check(self):
         try:
             return self.Initializer.start_check()
